=========
Tutorials
=========

These tutorials walk through how to use Covasim. If you want to explore them interactively, start a Jupyter environment in this folder (``docs/tutorials``). You can use either ``jupyter lab`` or ``jupyter notebook`` to run these tutorials.